@@ -25,6 +25,7 @@ define([
     //     pageThis: this,
     //     id: 'targetId',
     //     classes: '',
+    //     attrs: '', // data-idx, ...
     //     placeholder: '',
     //     select: function(value, dtype) {
     //         ;
@@ -49,15 +50,19 @@ define([
             super._init();
 
             this.prop = {
-                type: 'data',   // selector type : data / column
+                type: 'data',   // selector type : data / column / ml
                 pageThis: null, // target's page object
                 id: '',         // target id
                 value: null,    // pre-defined value
+                withPopup: true, // with filter button to show simple subset popup
                 finish: null,   // callback after selection (value, dtype)
                 select: null,   // callback after selection from suggestInput (value, dtype)
                 allowDataType: null, // list of allowed data types
+                dataCategory: null,  // list of data category (use it for ml categories)
                 // additional options
+                boxClasses: '',
                 classes: '',
+                attrs: '',
                 placeholder: 'Select variable',
                 required: false,
                 allowModule: false,
@@ -67,9 +72,20 @@ define([
             // If null, define default allow data type
             if (!this.prop.allowDataType) {
                 // default allow data types
-                this.prop.allowDataType = [
-                    'DataFrame', 'Series', 'ndarray', 'list', 'dict'
-                ]
+                if (this.prop.type === 'ml') {
+                    this.prop.allowDataType = vpConfig.getMLDataTypes();
+                } else {
+                    this.prop.allowDataType = [
+                        'DataFrame', 'Series', 'ndarray', 'list', 'dict'
+                    ]
+                }
+            }
+            if (!this.prop.dataCategory) {
+                if (this.prop.type === 'ml') {
+                    this.prop.dataCategory = vpConfig.getMLCategories();
+                } else {
+                    this.prop.dataCategory = this.prop.allowDataType;
+                }
             }
 
             this.state = {
@@ -93,7 +109,7 @@ define([
             }
 
             this._target = null;
-            if (this.prop.pageThis) {
+            if (this.prop.pageThis && this.prop.id !== '') {
                 this._target = this.prop.pageThis.wrapSelector('#' + this.prop.id);
             }
 
@@ -181,7 +197,7 @@ define([
                     autoFocus: true,
                     minLength: 0,
                     source: function (req, res) {
-                        var srcList = varList;
+                        var srcList = varList.filter(obj => that.prop.allowDataType.includes(obj.dtype));
                         var returlList = new Array();
                         for (var idx = 0; idx < srcList.length; idx++) {
                             // srcList as object array
@@ -226,6 +242,8 @@ define([
                     $(this).select();
                     $(this).autocomplete('search', $(this).val());
                 }).autocomplete('instance')._renderItem = function(ul, item) {
+                    $(ul).addClass('vp-scrollbar-vertical');
+                    $(ul).css('max-height', '250px');
                     return $('<li>').attr('data-value', item.value)
                             .append(`<div class="vp-sg-item">${item.label}<label class="vp-gray-text vp-cursor">&nbsp;| ${item.dtype}</label></div>`)
                             .appendTo(ul);
@@ -276,7 +294,11 @@ define([
                     that.renderVariableBox(that._varList.filter(obj => !that.prop.allowDataType.includes(obj.dtype)));
                 } else {
                     // filter variable list
-                    that.renderVariableBox(that._varList.filter(obj => obj.dtype == type));
+                    if (that.prop.type === 'ml') {
+                        that.renderVariableBox(that._varList.filter(obj => vpConfig.getMLDataDict(type).includes(obj.dtype)));
+                    } else {
+                        that.renderVariableBox(that._varList.filter(obj => obj.dtype == type));
+                    }
                 }
 
             });
@@ -356,19 +378,35 @@ define([
         templateForTarget() {
             let value = this.prop.value;
             if (value == undefined) {
-                value = this.prop.pageThis.state[this.prop.id] || '';
+                if (this.prop.id !== '') {
+                    value = this.prop.pageThis.state[this.prop.id] || '';
+                } else {
+                    value = '';
+                }
+            }
+            if (this.prop.withPopup === true) {
+                return `
+                    <div class="vp-ds-box vp-ds-box-${this.uuid} vp-ds-uninit ${this.prop.boxClasses}">
+                        <input type="text" class="vp-ds-target vp-input vp-state ${this.prop.classes}" 
+                                ${this.prop.attrs} 
+                                id="${this.prop.id}" value="${value}" 
+                                placeholder="${this.prop.placeholder}" ${this.prop.required?'required="required"':''}/>
+                        <span class="vp-ds-filter">
+                        <!-- LAB: img to url -->
+                        <!-- <img src="${com_Const.IMAGE_PATH}filter.svg"/> -->
+                        </span>
+                    </div>
+                `;
+            } else {
+                return `
+                    <div class="vp-ds-box vp-ds-box-${this.uuid} vp-ds-uninit ${this.prop.boxClasses}">
+                        <input type="text" class="vp-ds-target vp-input vp-state ${this.prop.classes}" 
+                                ${this.prop.attrs} 
+                                id="${this.prop.id}" value="${value}" 
+                                placeholder="${this.prop.placeholder}" ${this.prop.required?'required="required"':''}/>
+                    </div>
+                `;
             }
-            return `
-                <div class="vp-ds-box vp-ds-box-${this.uuid} vp-ds-uninit">
-                    <input type="text" class="vp-ds-target vp-input vp-state ${this.prop.classes}" 
-                            id="${this.prop.id}" value="${value}" 
-                            placeholder="${this.prop.placeholder}" ${this.prop.required?'required="required"':''}/>
-                    <span class="vp-ds-filter">
-                    <!-- LAB: img to url -->
-                    <!-- <img src="${com_Const.IMAGE_PATH}filter.svg"/> -->
-                    </span>
-                </div>
-            `;
         }
 
         templateForMultiSelector() {
@@ -508,7 +546,7 @@ define([
             let varTags = new com_String();
             let types = [
                 'All',
-                ...this.prop.allowDataType,
+                ...this.prop.dataCategory,
                 'Others'
             ];
             // Add Data Types to filter
@@ -529,10 +567,17 @@ define([
             let that = this;
             let varTags = new com_String();
             varTags = new com_String();
-            varList && varList.forEach((obj, idx) => {
-                varTags.appendFormatLine('<div class="{0} {1}" title="{2}" data-type="{3}">{4}</div>'
-                    , 'vp-ds-var-item', (that.state.data == obj.value?'selected':''), obj.dtype, obj.dtype, obj.label);
-            });
+            if (this.prop.type === 'ml') {
+                varList && varList.forEach((obj, idx) => {
+                    varTags.appendFormatLine('<div class="{0} {1}" title="{2}" data-type="{3}">{4}<span class="vp-gray-text"> | {5}</span></div>'
+                        , 'vp-ds-var-item', (that.state.data == obj.value?'selected':''), obj.dtype, obj.dtype, obj.label, obj.dtype);
+                });
+            } else {
+                varList && varList.forEach((obj, idx) => {
+                    varTags.appendFormatLine('<div class="{0} {1}" title="{2}" data-type="{3}">{4}</div>'
+                        , 'vp-ds-var-item', (that.state.data == obj.value?'selected':''), obj.dtype, obj.dtype, obj.label);
+                });
+            }
             $(this.wrapSelector('.vp-ds-variable-box')).html(varTags.toString());
 
             // focus on selected item
