@@ -15,7 +15,7 @@
 // CHROME: notebook/js/codemirror-ipython
 (function(mod) {
     if (typeof exports == "object" && typeof module == "object"){ // CommonJS
-        if (vpExtType === 'lab') {
+        if (vpExtType === 'lab' || vpExtType === 'lite') {
             mod(require("codemirror/lib/codemirror"),
             require("codemirror/mode/python/python")
             );
@@ -62,6 +62,7 @@ define([
     '../com_interface',
     './Component',
     './DataSelector',
+    './HelpViewer',
 
     /** codemirror */
     'codemirror/lib/codemirror',
@@ -70,7 +71,7 @@ define([
     'codemirror/addon/display/autorefresh',
     // 'notebook/js/codemirror-ipython' // LAB: disabled to avoid error FIXME:
 ], function(popupComponentHtml, popupComponentCss
-    , com_util, com_Const, com_String, com_interface, Component, DataSelector, codemirror
+    , com_util, com_Const, com_String, com_interface, Component, DataSelector, HelpViewer, codemirror
 ) {
     'use strict';
 
@@ -81,7 +82,7 @@ define([
      * Component
      */
     class PopupComponent extends Component {
-        constructor(state={ config: { id: 'popup', name: 'Popup title', path: 'path/file' }}, prop={}) {
+        constructor(state={ config: { id: 'popup', name: 'Popup title', path: 'path/file', category: '' }}, prop={}) {
             // CHROME: FIXME: #site -> .notebook-vertical
             // super($('#site'), state, prop);
             super($(vpConfig.parentSelector), state, prop);
@@ -107,14 +108,24 @@ define([
                 // show view box
                 codeview: true, 
                 dataview: true,
+                helpview: false,
                 // show footer
                 runButton: true,
                 footer: true,
+                // position and size
                 position: { right: 10, top: 120 },
                 size: { width: 400, height: 550 },
+                // additional modes and infos
                 saveOnly: false, // apply mode
+                resizable: true,
+                autoScroll: true,
                 checkModules: [], // module aliases or function names
                 docs: 'https://visual-python.gitbook.io/docs/getting-started/welcome-to-visual-python',
+                helpInfo: {
+                    content: '',   // method to show using help() ex) pd.DataFrame
+                    useHelp: true, // custom text to show on help viewer
+                    importCode: '' // import code for help
+                },
                 ...restConfig
             };
 
@@ -145,8 +156,9 @@ define([
             }
 
             this.cmCodeview = null;
-
             this.cmCodeList = [];
+
+            this.helpViewer = undefined;
         }
 
         wrapSelector(selector='') {
@@ -297,6 +309,22 @@ define([
 
         _bindEvent() {
             var that = this;
+            // Popup click / focus event
+            $(this.wrapSelector()).on('click focus', function(evt) {
+                // Close on blur
+                if ($(that.wrapSelector('.vp-popup-button')).find(evt.target).length == 0) {
+                    if (!$(evt.target).hasClass('vp-popup-codeview-box') 
+                    && $(that.wrapSelector('.vp-popup-codeview-box')).find(evt.target).length == 0) {
+                        that.closeView('code');
+                    }
+                }
+                if ($(that.wrapSelector('.vp-popup-button')).find(evt.target).length == 0) {
+                    if (!$(evt.target).hasClass('vp-popup-dataview-box') 
+                    && $(that.wrapSelector('.vp-popup-dataview-box')).find(evt.target).length == 0) {
+                        that.closeView('data');
+                    }
+                }
+            });
             // Close popup event
             $(this.wrapSelector('.vp-popup-close')).on('click', function(evt) {
                 if (that.getTaskType() === 'task') {
@@ -315,10 +343,7 @@ define([
             // Toggle operation (minimize)
             $(this.wrapSelector('.vp-popup-toggle')).on('click', function(evt) {
                 evt.stopPropagation();
-                $(that.eventTarget).trigger({
-                    type: 'close_option_page',
-                    component: that
-                });
+                that.hide();
             });
             // Maximize operation
             $(this.wrapSelector('.vp-popup-maximize')).on('click', function(evt) {
@@ -359,6 +384,9 @@ define([
                 // add install codes
                 var codes = that.generateInstallCode();
                 codes && codes.forEach(code => {
+                    if (vpConfig.extensionType === 'lite') {
+                        code = code.replace('!', '%');
+                    }
                     com_interface.insertCell('code', code, true, that.getSigText());
                 });
             });
@@ -398,6 +426,11 @@ define([
                 that._saveSingleState($(this)[0]);
             });
 
+            // click input box with selection
+            $(document).on('focus', this.wrapSelector('input'), function() {
+                $(this).select();
+            });
+
             // Click buttons
             $(this.wrapSelector('.vp-popup-button')).on('click', function(evt) {
                 var btnType = $(this).data('type');
@@ -418,6 +451,14 @@ define([
                         }
                         evt.stopPropagation();
                         break;
+                    case 'help':
+                        if ($(that.wrapSelector('.vp-popup-dataview-box')).is(':hidden')) {
+                            that.openView('help');
+                        } else {
+                            that.closeView('help');
+                        }
+                        evt.stopPropagation();
+                        break;
                     case 'cancel':
                         if (that.getTaskType() === 'task') {
                             $(that.eventTarget).trigger({
@@ -433,9 +474,10 @@ define([
                         }
                         break;
                     case 'run':
-                        let result = that.run();
+                        var result = that.run();
                         if (result) {
-                            that.save();
+                            // that.save();
+                            that.close();
                         }
                         break;
                     case 'show-detail':
@@ -451,15 +493,22 @@ define([
             $(this.wrapSelector('.vp-popup-detail-button')).on('click', function(evt) {
                 var btnType = $(this).data('type');
                 switch(btnType) {
-                    case 'apply':
-                        that.save();
-                        break;
-                    case 'add':
-                        let result = that.run(false);
+                    // case 'apply':
+                    //     that.save();
+                    //     break;
+                    case 'run-save':
+                        var result = that.run();
                         if (result) {
                             that.save();
                         }
                         break;
+                    case 'add':
+                        var result = that.run(false);
+                        if (result) {
+                            // that.save();
+                            that.close();
+                        }
+                        break;
                 }
             });
             // Close event for inner popup
@@ -479,6 +528,14 @@ define([
                 }
             });
 
+            // blur on code, dataview
+            $(this.wrapSelector('.vp-popup-codeview-box')).on('hide', function() {
+                that.closeView('code');
+            }); 
+            $(this.wrapSelector('.vp-popup-dataview-box')).on('hide', function() {
+                that.closeView('data');
+            }); 
+
             // focus on data selector input
             $(this.wrapSelector('.vp-data-selector')).on('focus', function(evt) {
                 
@@ -492,12 +549,13 @@ define([
 
         _unbindEvent() {
             $(document).off('change', this.wrapSelector('.vp-state'));
+            $(document).off('focus', this.wrapSelector('input'));
         }
 
         _bindDraggable() {
             var that = this;
             let containment = 'body';
-            if (vpConfig.extensionType === 'lab') {
+            if (vpConfig.extensionType === 'lab' || vpConfig.extensionType === 'lite') {
                 containment = '#main';
             }
             $(this.wrapSelector()).draggable({
@@ -544,7 +602,11 @@ define([
             this.$pageDom = $(popupComponentHtml.replaceAll('${vp_base}', com_Const.BASE_PATH));
             // set title
             // this.$pageDom.find('.vp-popup-title').text(this.category + ' > ' + this.name);
-            this.$pageDom.find('.vp-popup-title').html(`<span class="vp-popup-category">${this.category} > </span><span>${this.name}</span>`);
+            if (this.category && this.category !== '') {
+                this.$pageDom.find('.vp-popup-title').html(`<span class="vp-popup-category">${this.category} > </span><span>${this.name}</span>`);
+            } else {
+                this.$pageDom.find('.vp-popup-title').html(`<span>${this.name}</span>`);
+            }
             // set body
             let bodyTemplate = this.templateForBody();
             // CHROME: check url keyword and replace it
@@ -570,8 +632,8 @@ define([
 
             let { 
                 installButton, importButton, packageButton, 
-                codeview, dataview, runButton, footer, 
-                sizeLevel, position, docs
+                codeview, dataview, helpview, runButton, footer, 
+                sizeLevel, position, autoScroll, docs
             } = this.config;
 
             // apply link to docs
@@ -606,6 +668,9 @@ define([
             if (!dataview) {
                 $(this.wrapSelector('.vp-popup-button[data-type="data"]')).hide();
             }
+            if (!helpview) {
+                $(this.wrapSelector('.vp-popup-button[data-type="help"]')).hide();
+            }
 
             // run button
             if (!runButton) {
@@ -637,6 +702,10 @@ define([
                     break;
             }
 
+            if (autoScroll) {
+                $(this.wrapSelector('.vp-popup-body')).addClass('vp-scrollbar');
+            }
+
             // set detailed size
             $(this.wrapSelector()).css({
                 width: this.config.size.width + 'px',
@@ -652,7 +721,9 @@ define([
             }
 
             this._bindDraggable();
-            this._bindResizable();
+            if (this.config.resizable) {
+                this._bindResizable();
+            }
         }
         
         templateForInnerPopup() {
@@ -754,9 +825,8 @@ define([
             vpLog.display(VP_LOG_TYPE.DEVELOP, 'savedState', that.state);   
         }
 
-        _saveSingleState(tag) {
+        _getTagValue(tag) {
             let id = tag.id;
-            let customKey = $(tag).data('key');
             let tagName = $(tag).prop('tagName'); // returns with UpperCase
             let newValue = '';
             switch(tagName) {
@@ -787,12 +857,21 @@ define([
                     }
                     break;
             }
+            return newValue;
+        }
+
+        _saveSingleState(tag) {
+            let id = tag.id;
+            let customKey = $(tag).data('key');
             
+            let newValue = this._getTagValue(tag);
             // if custom key is available, use it
             if (customKey && customKey != '') {
                 // allow custom key until level 2
                 let customKeys = customKey.split('.');
-                if (customKeys.length == 2) {
+                if (customKeys.length === 3) {
+                    this.state[customKeys[0]][customKeys[1]][customKeys[2]] = newValue;
+                } else if (customKeys.length === 2) {
                     this.state[customKeys[0]][customKeys[1]] = newValue;
                 } else {
                     this.state[customKey] = newValue;
@@ -843,9 +922,23 @@ define([
                 }
             }
 
+            if (requiredFilled) {
+                requiredFilled = this.checkBeforeRun();
+            }
+
             return requiredFilled;
         }
 
+        /**
+         * Check options and do some operation before run
+         * @returns {boolean} check options and returns true or false (false will stop code running)
+         */
+        checkBeforeRun() {
+            /** Implementation needed */
+
+            return true;
+        }
+
         checkAndRunModules(execute=true, background=false) {
             let sigText = this.getSigText();
 
@@ -904,35 +997,62 @@ define([
             return true;
         }
 
+        _beforeOpen() {
+            /** Implementation needed - Generated on clicking Install Package button */
+        }
+
         /**
          * Open popup
          * - show popup
          * - focus popup
          * - bind codemirror
          */
-        open() {
+        open(targetFrame=undefined) {
             vpLog.display(VP_LOG_TYPE.DEVELOP, 'open popup', this);
             this.loadState();
             
-            this.show();
-
-            // set popup position if its top-left side is outside of view
-            let pos = $(this.wrapSelector()).position();
-            if (pos) {
-                if (pos.top < 0) {
-                    $(this.wrapSelector()).css({ top: 0 });
-                }
-                if (pos.left < 0) {
-                    $(this.wrapSelector()).css({ left: 0 });
+            this._beforeOpen();
+            if (targetFrame !== undefined) {
+                // hide popup frame
+                $(this.wrapSelector('.vp-popup-header')).hide();
+                $(this.wrapSelector('.vp-popup-footer')).hide();
+                // set width and height to 100%
+                $(this.wrapSelector()).css({
+                    width: '100%',
+                    height: '100%',
+                    'min-height': 'unset',
+                    display: 'block',
+                    position: 'initial',
+                    border: '0px'
+                });
+                $(this.wrapSelector('.vp-popup-body')).css({
+                    padding: '0px'
+                });
+                // show on targetFrame
+                $(this.wrapSelector()).appendTo($(targetFrame));
+            } else {
+                this.show();
+    
+                // set popup position if its top-left side is outside of view
+                let pos = $(this.wrapSelector()).position();
+                if (pos) {
+                    if (pos.top < 0) {
+                        $(this.wrapSelector()).css({ top: 0 });
+                    }
+                    if (pos.left < 0) {
+                        $(this.wrapSelector()).css({ left: 0 });
+                    }
                 }
             }
 
             this._bindCodemirror();
 
-            $(this.eventTarget).trigger({
-                type: 'focus_option_page',
-                component: this
-            });
+            if (targetFrame == undefined) {
+                $(this.eventTarget).trigger({
+                    type: 'focus_option_page',
+                    component: this
+                });
+            }
         }
 
         setSaveOnlyMode() {
@@ -949,7 +1069,15 @@ define([
         close() {
             vpLog.display(VP_LOG_TYPE.DEVELOP, 'close popup', this);
             this.saveState();
-            this.hide();
+            if (this.getTaskType() === 'task') {
+                $(this.eventTarget).trigger({
+                    type: 'remove_option_page',
+                    component: this
+                });
+            } else {
+                // if it's block, just hide it
+                this.hide();
+            }
         }
 
         save() {
@@ -966,7 +1094,9 @@ define([
 
         remove() {
             vpLog.display(VP_LOG_TYPE.DEVELOP, 'remove popup', this);
+            this._unbindResizable();
             this._unbindEvent();
+            this.closeHelpView();
             $(this.wrapSelector()).remove();
         }
 
@@ -983,6 +1113,10 @@ define([
 
         blur() {
             $(this.wrapSelector()).removeClass('vp-focused');
+            // blur on its block
+            if (this.taskItem) {
+                this.taskItem.blurItem();
+            }
         }
 
         show() {
@@ -999,6 +1133,7 @@ define([
         }
 
         hide() {
+            this.closeHelpView();
             this.taskItem && this.taskItem.blurItem();
             $(this.wrapSelector()).hide();
         }
@@ -1037,7 +1172,7 @@ define([
          * @param {*} viewType code / data
          */
         openView(viewType) {
-            if (viewType == 'code') {
+            if (viewType === 'code') {
                 this.saveState();
                 var code = this.generateCode();
                 let codeText = '';
@@ -1053,19 +1188,72 @@ define([
                 setTimeout(function() {
                     that.cmCodeview.refresh();
                 }, 1);
-                $(this.wrapSelector('.vp-popup-dataview-box')).hide();
-            } else {
+                this.closeView('data');
+                $(this.wrapSelector('.vp-popup-codeview-box')).show();
+            } else if (viewType === 'data') {
                 this.renderDataView();
-                $(this.wrapSelector('.vp-popup-codeview-box')).hide();
+                this.closeView('code');
+                $(this.wrapSelector('.vp-popup-dataview-box')).show();
+            } else if (viewType === 'help') {
+                this.closeView('code');
+                this.closeView('data');
+                this.openHelpView();
             }
-
-            $(this.wrapSelector('.vp-popup-'+viewType+'view-box')).show();
         }
 
         closeView(viewType) {
+            if (viewType === 'code') {
+                // reset codeview
+                if (this.cmCodeview) {
+                    this.cmCodeview.setValue('');
+                    this.cmCodeview.save();
+        
+                    var that = this;
+                    setTimeout(function() {
+                        that.cmCodeview.refresh();
+                    }, 1);
+                }
+            } else if (viewType === 'data') {
+                // reset dataview
+                $(this.wrapSelector('.vp-popup-dataview-box')).html('');
+            }
+            // hide view
             $(this.wrapSelector('.vp-popup-'+viewType+'view-box')).hide();
         }
 
+        /**
+         * Open HelpViewer
+         * - only one helpviewer at once
+         */
+        openHelpView() {
+            this.closeHelpView();
+            this.helpViewer = new HelpViewer();
+            this.helpViewer.open(this.config.helpInfo.content, this.config.helpInfo.useHelp, this.config.helpInfo.importCode);
+        }
+
+        /**
+         * Close helpViewer
+         */
+        closeHelpView() {
+            if (this.helpViewer !== undefined) {
+                this.helpViewer.remove();
+            }
+        }
+
+        /**
+         * Set HelpViewer content
+         * @param {string} content 
+         * @param {boolean} useHelp 
+         * @param {string} importCode
+         */
+        setHelpContent(content, useHelp=true, importCode='') {
+            this.config.helpInfo = {
+                content: content,
+                useHelp: useHelp,
+                importCode: importCode
+            };
+        }
+
         /**
          * Open inner popup box
          */
