@@ -18,10 +18,11 @@ define([
     'vp_base/js/com/com_util',
     'vp_base/js/com/com_Const',
     'vp_base/js/com/com_String',
+    'vp_base/js/com/com_interface',
     'vp_base/js/com/component/PopupComponent',
     'vp_base/js/com/component/FileNavigation',
     'vp_base/js/com/component/LoadingSpinner'
-], function(snHtml, snCss, com_util, com_Const, com_String, PopupComponent, FileNavigation, LoadingSpinner) {
+], function(snHtml, snCss, com_util, com_Const, com_String, com_interface, PopupComponent, FileNavigation, LoadingSpinner) {
 
     /**
      * Snippets
@@ -471,14 +472,16 @@ define([
                     let cmCode = that.codemirrorList[title];
                     cmCode.save();
                     var code = cmCode.getValue();
+                    // DEPRECATED: no longer save to block as default
                     // create block and run it
-                    $('#vp_wrapper').trigger({
-                        type: 'create_option_page', 
-                        blockType: 'block',
-                        menuId: 'lgExe_code',
-                        menuState: { taskState: { code: code } },
-                        afterAction: 'run'
-                    });
+                    // $('#vp_wrapper').trigger({
+                    //     type: 'create_option_page', 
+                    //     blockType: 'block',
+                    //     menuId: 'lgExe_code',
+                    //     menuState: { taskState: { code: code } },
+                    //     afterAction: 'run'
+                    // });
+                    com_interface.insertCell('code', code, true, 'Data Analysis > Snippets');
                 } else if (menu == 'duplicate') {
                     var dupNo = 1;
                     var timestamp = new Date().getTime();
@@ -666,21 +669,23 @@ define([
             // load udf list to table 'vp_udfList'
             let loadingSpinner = new LoadingSpinner($(this.wrapSelector('.vp-sn-table')));
             vpConfig.getData().then(function(udfObj) {
-                vpLog.display(VP_LOG_TYPE.DEVELOP, udfObj);
+                vpLog.display(VP_LOG_TYPE.DEVELOP, 'Snippets get data', udfObj);
                 var snippets = new com_String();
-                Object.keys(udfObj).forEach(key => {
-                    let obj = udfObj[key];
-                    if (obj.code != null && obj.code != undefined) {
-    
-                        var hasImported = false;
-                        if (that.importedList.includes(key)) {
-                            // set new label
-                            hasImported = true;
+                if (udfObj !== undefined) {
+                    Object.keys(udfObj).forEach(key => {
+                        let obj = udfObj[key];
+                        if (obj.code != null && obj.code != undefined) {
+        
+                            var hasImported = false;
+                            if (that.importedList.includes(key)) {
+                                // set new label
+                                hasImported = true;
+                            }
+                            var item = that.renderSnippetItem(key, obj.code, obj.timestamp, hasImported);
+                            snippets.append(item);
                         }
-                        var item = that.renderSnippetItem(key, obj.code, obj.timestamp, hasImported);
-                        snippets.append(item);
-                    }
-                });
+                    });
+                }
                 $(that.wrapSelector('.vp-sn-table')).html(snippets.toString());
 
                 // bind snippet item
@@ -693,7 +698,8 @@ define([
                     that.bindCodeMirror(title, tag);
                 });
             }).catch(function(err) {
-                com_util.renderAlertModal(err);
+                // com_util.renderAlertModal(err);
+                vpLog.display(VP_LOG_TYPE.ERROR, err);
             }).finally(function() {
                 loadingSpinner.remove();
             });
