@@ -18,12 +18,13 @@ define([
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_generatorV2',
     'vp_base/js/com/com_util',
+    'vp_base/js/com/com_interface',
     'vp_base/js/com/component/PopupComponent',
     'vp_base/js/com/component/SuggestInput',
     'vp_base/js/com/component/VarSelector2',
     'vp_base/data/m_visualize/seabornLibrary',
     'vp_base/js/com/component/DataSelector'
-], function(chartHTml, chartCss, com_String, com_generator, com_util, PopupComponent, SuggestInput, VarSelector2, SEABORN_LIBRARIES, DataSelector) {
+], function(chartHTml, chartCss, com_String, com_generator, com_util, com_interface, PopupComponent, SuggestInput, VarSelector2, SEABORN_LIBRARIES, DataSelector) {
 
     class Seaborn extends PopupComponent {
         _init() {
@@ -361,29 +362,33 @@ define([
                 let val = $(this).val();
                 if (val !== '') {
                     // enable xticks_label
-                    $(that.wrapSelector('#xticks_label')).prop('readonly', false);
+                    $(that.wrapSelector('#xticks_label')).attr('readonly', false);
                 } else {
                     // disable xticks_label
-                    $(that.wrapSelector('#xticks_label')).prop('readonly', true);
+                    $(that.wrapSelector('#xticks_label')).attr('readonly', true);
                 }
             });
             $(this.wrapSelector('#yticks')).on('change', function() {
                 let val = $(this).val();
                 if (val !== '') {
                     // enable yticks_label
-                    $(that.wrapSelector('#yticks_label')).prop('readonly', false);
+                    $(that.wrapSelector('#yticks_label')).attr('readonly', false);
                 } else {
                     // disable yticks_label
-                    $(that.wrapSelector('#yticks_label')).prop('readonly', true);
+                    $(that.wrapSelector('#yticks_label')).attr('readonly', true);
                 }
             });
 
             // axes - ticks label: inform user to type location option to use label
-            $(this.wrapSelector('#xticks_label[readonly]')).on('click', function() {
-                $(that.wrapSelector('#xticks')).focus();
+            $(this.wrapSelector('#xticks_label')).on('click', function() {
+                if ($(that.wrapSelector('#xticks')).val() === '') {
+                    $(that.wrapSelector('#xticks')).focus();
+                }
             });
-            $(this.wrapSelector('#yticks_label[readonly]')).on('click', function() {
-                $(that.wrapSelector('#yticks')).focus();
+            $(this.wrapSelector('#yticks_label')).on('click', function() {
+                if ($(that.wrapSelector('#yticks')).val() === '') {
+                    $(that.wrapSelector('#yticks')).focus();
+                }
             });
 
             // preview refresh
@@ -766,14 +771,16 @@ define([
         handleInnerOk() {
             // generateImportCode
             var code = this.generateImportCode();
+            // DEPRECATED: no longer save to block as default
             // create block and run it
-            $('#vp_wrapper').trigger({
-                type: 'create_option_page', 
-                blockType: 'block',
-                menuId: 'lgExe_code',
-                menuState: { taskState: { code: code } },
-                afterAction: 'run'
-            });
+            // $('#vp_wrapper').trigger({
+            //     type: 'create_option_page', 
+            //     blockType: 'block',
+            //     menuId: 'lgExe_code',
+            //     menuState: { taskState: { code: code } },
+            //     afterAction: 'run'
+            // });
+            com_interface.insertCell('code', code, true, 'Visualization > Seaborn');
 
             this.closeInnerPopup();
 
